==> haskell-first-class-families-0.8.1.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 first-class-families
version:              0.8.1.0
visibility:           public
id:                   first-class-families-0.8.1.0-7nk8sVtYj7D22wXygDy92
key:                  first-class-families-0.8.1.0-7nk8sVtYj7D22wXygDy92
license:              MIT
copyright:            2018-2024 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First-class type families
description:
    A library for type-level programming.

    See README.

category:             Other
abi:                  d1519cd3d04dd5f7eaed7a96927c885b
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-first-class-families
hs-libraries:         HSfirst-class-families-0.8.1.0-7nk8sVtYj7D22wXygDy92
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-first-class-families-0.8.2.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 first-class-families
version:              0.8.2.0
visibility:           public
id:                   first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
key:                  first-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
license:              MIT
copyright:            2018-2025 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First-class type families
description:
    A library for type-level programming.

    See README.

category:             Other
abi:                  448d5c072194a83ef61665a0fa5b29d1
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/first-class-families-0.8.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-first-class-families
hs-libraries:         HSfirst-class-families-0.8.2.0-HzUnQisuAnjGuL9m7M0Ger
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
